@@ -10,18 +10,18 @@ has 'support_async' => sub { 0 };
 has 'serialiser';
 
 sub get_serialiser {
-	my ($self) = @_;
-	if(!$self->serialiser && $self->config->{serialiser}) {
-		eval {
-			eval "require $self->config->{serialiser};";
-			warn("Require failed: $@") if $self->config->{debug} && $@;
-			my $serialiser = $self->config->{serialiser}->new;
-			$serialiser->config($self->config);
-			$self->serialiser($serialiser);
-		};
-		die("Failed to load serialiser $self->config->{serialiser}: $@") if $@;
-	}
-	return $self->serialiser;
+    my ($self) = @_;
+    if(!$self->serialiser && (my $s = $self->config->{serialiser})) {
+        eval {
+            eval "require $s;";
+            warn("Require failed: $@") if $self->config->{debug} && $@;
+            my $serialiser = $self->config->{serialiser}->new;
+            $serialiser->config($self->config);
+            $self->serialiser($serialiser);
+        };
+        die("Failed to load serialiser $s: $@") if $@;
+    }
+    return $self->serialiser;
 }
 
 sub get { die("Must be overridden in backend module") };
