@@ -6,11 +6,15 @@ use Mojo::Base 'MojoX::Plugin::AnyCache::Serialiser';
 
 use Data::MessagePack;
 
+use MIME::Base64;
+
 sub deserialise {
     my ($self, $data) = @_;
 
     return unless defined $data;
 
+    $data = decode_base64($data);
+
     # TODO implement serialiser configuration
     my $mp = Data::MessagePack->new();
     $mp->prefer_integer(0);
@@ -28,7 +32,7 @@ sub serialise {
     $mp->prefer_integer(0);
     $data = $mp->pack( $data );
 
-    return $data;
+    return encode_base64($data);
 }
 
 1;
